@@ -1,9 +1,14 @@
+import numpy as np
+
+
 class SupportDataVariable:
     __slots__ = ("name", "values", 'attributes')
 
     def __init__(self, name, values, attributes):
         self.name = name
         self.values = values
+        if type(self.values) is list:
+            self.values = np.array(self.values)
         self.attributes = attributes
 
     def __len__(self):
